@@ -25,7 +25,7 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 from __future__ import unicode_literals
 
-version = '0.5.10'
+version = '0.5.11'
 
 import re
 import inspect
@@ -101,6 +101,11 @@ except ImportError:
     ssl = None
 
 
+ClassTypes = (type,)
+if not PY3:
+    ClassTypes = (type, types.ClassType)
+
+
 class HTTPrettyError(Exception):
     pass
 
@@ -715,6 +720,7 @@ class HTTPretty(Py3kObject):
     PATCH = b'PATCH'
     METHODS = (GET, PUT, POST, DELETE, HEAD, PATCH)
     last_request = HTTPrettyRequestEmpty()
+    _is_enabled = False
 
     @classmethod
     def reset(cls):
@@ -777,6 +783,7 @@ class HTTPretty(Py3kObject):
 
     @classmethod
     def disable(cls):
+        cls._is_enabled = False
         socket.socket = old_socket
         socket.SocketType = old_socket
         socket._socketobject = old_socket
@@ -811,8 +818,13 @@ class HTTPretty(Py3kObject):
                 ssl.sslwrap_simple = old_sslwrap_simple
                 ssl.__dict__['sslwrap_simple'] = old_sslwrap_simple
 
+    @classmethod
+    def is_enabled(cls):
+        return cls._is_enabled
+
     @classmethod
     def enable(cls):
+        cls._is_enabled = True
         socket.socket = fakesock.socket
         socket._socketobject = fakesock.socket
         socket.SocketType = fakesock.socket
@@ -851,12 +863,29 @@ class HTTPretty(Py3kObject):
 
 def httprettified(test):
     "A decorator tests that use HTTPretty"
-    @functools.wraps(test)
-    def wrapper(*args, **kw):
-        HTTPretty.reset()
-        HTTPretty.enable()
-        try:
-            return test(*args, **kw)
-        finally:
-            HTTPretty.disable()
-    return wrapper
+    def decorate_class(klass):
+        for attr in dir(klass):
+            if not attr.startswith('test_'):
+                continue
+
+            attr_value = getattr(klass, attr)
+            if not hasattr(attr_value, "__call__"):
+                continue
+
+            setattr(klass, attr, decorate_callable(attr_value))
+        return klass
+
+    def decorate_callable(test):
+        @functools.wraps(test)
+        def wrapper(*args, **kw):
+            HTTPretty.reset()
+            HTTPretty.enable()
+            try:
+                return test(*args, **kw)
+            finally:
+                HTTPretty.disable()
+        return wrapper
+
+    if isinstance(test, ClassTypes):
+        return decorate_class(test)
+    return decorate_callable(test)
